@@ -13,7 +13,6 @@
 int main(int argc, char *argv[])
 {
     int status;
-    sox_format_init();
 
     QApplication a(argc, argv);
     QTranslator trans;
@@ -29,6 +28,5 @@ int main(int argc, char *argv[])
     QHiMDMainWindow w;
     w.show();
     status = a.exec();
-    sox_format_quit();
     return status;
 }
